// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.
//*****************************************************************************
// common.h
//

//
// Common include file for the palrt code.
//*****************************************************************************

#ifndef _COMMON_H_
#define _COMMON_H_

#include <switches.h>
#include <winwrap.h>
#include <minipal/utils.h>
#endif // _COMMON_H_
